#
# spec file for package fio
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%ifnarch s390x s390 ppc64le ppc64 ppc %{ix86} %{arm}
%bcond_without librbd
%endif
%ifarch x86_64
%bcond_without libpmem
%endif
%ifnarch s390x s390 %{arm}
%bcond_without libnuma
%endif
%bcond_without librdmacm
Name:           fio
Version:        3.36
Release:        1.1
Summary:        Flexible I/O tester
License:        GPL-2.0-only
Group:          System/Benchmark
URL:            https://git.kernel.dk/?p=fio.git;a=summary
Source:         https://brick.kernel.dk/snaps/fio-%{version}.tar.bz2
BuildRequires:  cunit-devel
BuildRequires:  gtk2-devel
BuildRequires:  libaio-devel
BuildRequires:  libcurl-devel
BuildRequires:  libiscsi-devel
BuildRequires:  libnbd-devel
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
Suggests:       gfio
Suggests:       gnuplot
%if 0%{?is_opensuse}
BuildRequires:  glusterfs-devel
%endif
%if %{with libnuma}
BuildRequires:  libnuma-devel
%endif
%if %{with librbd}
BuildRequires:  librbd-devel
%endif
%if %{with libpmem}
BuildRequires:  libpmem-devel
BuildRequires:  libpmemblk-devel
%endif
%if %{with librdmacm}
BuildRequires:  librdmacm-devel
%endif

%description
fio is an I/O tool meant to be used both for benchmark and stress/hardware
verification. It has support for 4 different types of I/O engines (sync,
mmap, libaio, posixaio), I/O priorities (for newer Linux kernels), rate I/O,
forked or threaded jobs, and much more. It can work on block devices as
well as files. fio accepts job descriptions in a simple-to-understand text
format. Several example job files are included. fio displays all sorts of
I/O performance information, such as completion and submission latencies
(avg/mean/deviation), bandwidth stats, cpu and disk utilization, and more.

%package -n gfio
Summary:        Graphical front end for fio
Group:          System/Benchmark
Requires:       %{name} = %{version}

%description -n gfio
gfio is a gtk based graphical front-end for fio.  It is often installed on the
testers workstation whereas fio would be installed on the server.

%prep
%setup -q

%build
sed -i "s|%{_bindir}/bash|/bin/bash|g" tools/genfio
sed -i "s|-O3|%{optflags}|g" Makefile
# Not autotools configure
./configure \
  --enable-gfio \
  --enable-libiscsi \
  --enable-libnbd \
  --disable-native
%make_build

%install
%make_install \
  prefix="%{_prefix}" \
  mandir="%{_mandir}"

# Drop py2 only tool
rm %{buildroot}%{_bindir}/fio-histo-log-pctiles.py

# fix rpmlint
sed -i 's/\/usr\/bin\/env python3/\/usr\/bin\/python3/' %{buildroot}%{_bindir}/fio*

%check
%make_build test

%files
%license COPYING MORAL-LICENSE
%doc README.rst examples
%doc HOWTO.rst REPORTING-BUGS
%doc GFIO-TODO SERVER-TODO STEADYSTATE-TODO
%{_bindir}/fio
%{_bindir}/fiologparser.py
%{_bindir}/fio_generate_plots
%{_bindir}/genfio
%{_bindir}/fio2gnuplot
%{_bindir}/fio-btrace2fio
%{_bindir}/fio-dedupe
%{_bindir}/fio-genzipf
%{_bindir}/fio-verify-state
%{_bindir}/fiologparser_hist.py
%{_bindir}/fio_jsonplus_clat2csv
%{_datadir}/fio
%{_mandir}/man1/fio.1%{?ext_man}
%{_mandir}/man1/fio_generate_plots.1%{?ext_man}
%{_mandir}/man1/fio2gnuplot.1%{?ext_man}
%{_mandir}/man1/fiologparser_hist.py.1%{?ext_man}

%files -n gfio
%{_bindir}/gfio

%changelog
* Tue Nov 21 2023 Dirk Müller <dmueller@suse.com>
- update to 3.36:
  * https://git.kernel.dk/?p=fio.git;a=shortlog;h=refs/tags/fio-3.36
* Sun Jun 11 2023 Dirk Müller <dmueller@suse.com>
- update to 3.35:
  * https://git.kernel.dk/?p=fio.git;a=shortlog;h=refs/tags/fio-3.35
* Fri May  5 2023 Martin Pluskal <mpluskal@suse.com>
- Enable iscsi and nbd
- Small spec file cleanup
* Fri Mar 17 2023 Dirk Müller <dmueller@suse.com>
- update to 3.34:
  * https://git.kernel.dk/?p=fio.git;a=shortlog;h=refs/tags/fio-3.34
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 3.33:
  * https://git.kernel.dk/?p=fio.git;a=shortlog;h=refs/tags/fio-3.33
* Wed Sep 14 2022 Marcelo Martins <mmartins@suse.com>
- update to 3.32:
  * https://git.kernel.dk/?p=fio.git;a=shortlog;h=refs/tags/fio-3.32
* Tue Apr 19 2022 Alberto Planas Dominguez <aplanas@suse.com>
- update to 3.30:
  * https://git.kernel.dk/?p=fio.git;a=shortlog;h=refs/tags/fio-3.30
* Mon Dec 20 2021 Dirk Müller <dmueller@suse.com>
- update to 3.29:
  * io_uring fixes
  * io_uring: fix bandwidth calculation
  * fix for loop count when do_verify=0
  * zbd: fix unexpected job termination by open zone search failure
* Sun Sep 19 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 3.28. No changelog.
- Spec cleanup.
* Tue Apr 20 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.26 (no changelog)
* Thu Dec 17 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.25 (no changelog)
* Sun Sep 13 2020 dsterba@suse.cz
- Update to 3.23 (no changelog)
* Fri Jul 24 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.21 (no changelog)
- Remove fio-gfio_main_ui.patch
* Fri Jun  5 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.20:
  * No changelog available
- Add fio-gfio_main_ui.patch
* Thu May 21 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.19 (no changelog)
- Remove 0001-Fix-compilation-error-with-gfio.patch
- Remove fio.python2.patch
* Mon Oct  7 2019 dsterba@suse.cz
- Update to version 3.16:
  * new: NBD support
  * new: ZBD support
  * for the rest see http://brick.kernel.dk/snaps/fio-3.16.shortlog.txt
- Added patches:
  * 0001-Fix-compilation-error-with-gfio.patch
* Wed Jul  3 2019 terekhov <termim@gmail.com>
- Update to version 3.14:
  * no upstream changelog available
* Fri Feb 22 2019 Lars Marowsky-Bree <lmb@suse.com>
- Update to version 3.13:
  * Shortlog: http://brick.kernel.dk/snaps/fio-3.13.shortlog.txt
* Wed Nov 14 2018 jkohoutek@suse.com
- Update to version 3.12:
  * no upstream changelog available
* Fri Sep 21 2018 Martin Pluskal <mpluskal@suse.com>
- Do not use libressl
* Wed Sep 19 2018 Lars Marowsky-Bree <lmb@suse.com>
- Remove duplication from build macros
- Disable building for native host to avoid illegal instruction crashes
* Fri Sep 14 2018 Lars Marowsky-Bree <lmb@suse.com>
- Update to version 3.10
  * For detailed list of changes see:
    http://brick.kernel.dk/snaps/fio-3.10.shortlog.txt
- Switch to building with openssl
* Fri Sep  7 2018 Lars Marowsky-Bree <lmb@suse.com>
- Update to version 3.9
  * For detailed list of changes see:
    http://brick.kernel.dk/snaps/fio-3.9.shortlog.txt
* Wed Apr 25 2018 olaf@aepfle.de
- Replace hardcoded dependency to python2.7, which does not exist
  in SLE_11, with python2 via fio.python2.patch
* Thu Mar 29 2018 jeffm@suse.com
- Update license tag to read "GPL-2.0"
* Thu Mar 29 2018 jeffm@suse.com
- Allow to build on SLE11 again:
  - %%licence -> %%doc on old rpm
  - No dependencies on libnuma (i386), librbd, and libpmem.
* Thu Mar  8 2018 mpluskal@suse.com
- Rework conditionals
- Update spec file with spec-clener
* Wed Mar  7 2018 lmb@suse.com
- Enable building of the rbd support on aarch64 for SLE (bsc#1083445)
* Sun Feb 18 2018 avindra@opensuse.org
- Update to version 3.4:
  * For detailed list of changes see:
    http://brick.kernel.dk/snaps/fio-3.4.shortlog.txt
- simplify build and install
* Mon Jan  8 2018 mpluskal@suse.com
- Update to version 3.3:
  * For detailed list of changes see:
    http://brick.kernel.dk/snaps/fio-3.3.shortlog.txt
* Mon Nov 13 2017 mpluskal@suse.com
- Correct bash location in genfio
* Thu Nov  9 2017 jzelazkova@suse.com
- Update to version 3.2:
  * no upstream changelog available
* Fri Sep  1 2017 mpluskal@suse.com
- Update describtion and provide more documents
* Fri Jul 28 2017 mpluskal@suse.com
- Update to version 2.99
  * No changelog available
* Thu Jun 29 2017 ktsamis@suse.com
- Update to version 2.21:
  * See http://brick.kernel.dk/snaps/fio-2.21.shortlog.txt
- Enabled tests
* Sat May 27 2017 david.bahi@dell.com
- Update to version 2.20:
  * stat: Re-add output of basic bw information if bw_log is not written
  * Fix wrap issue with 64-bit pwritev2/preadv2
  * options: force refill_buffers with pattern and any reads
  * gettime: make utime_since_now and mtime_since_now consistent in how they record the caller and put this all behind FIO_DEBUG_TIME
  * client/server: make sure that all elements in io_u_lat_m[] are transferred and received
  * stat: reset_io_stats: fix a problem, rearrange some code
  * remove redundant _fio_rbd_disconnect, which is already called in fio_rbd_cleaup
  * os/os-android.h: fix shared memory support
  * Drop triple X for cpu affinity for OpenBSD
  * Implement shm_attach_to_open_removed() for OpenBSD
  * Turn off lex by default on OpenBSD
  * os/os-linux.h: fix broken byte swap intrinsics
  * os/os-android.h: use byte swap intrinsics if available
  * os/os-android.h: fix broken shmget() due to ndk-r15
  * fio.h: zero old flag bits when setting new ioengine flags
  * configure: fix broken test for cuda
  * thread_options: kill two unused pads
  * server: bump protocol version
  * gpu: kill a lot of useless ifdefs
  * gpu: ensure that we convert gpu_dev_id options
  * GPUDirect RDMA support
  * seqlock: add simple user space code for sequence locks
  * Drop the only local variable declaration within a for-loop (C99)
  * Fix num2str() output when modulo != -1U
  * stat: cleanup iops/bw logging functions
  * stat: make next log time decision cleaner
  * Return non-negtive error in order to print right error msg
  * doc: add ftruncate engine documentation and example jobfile
  * Fix num2str() output when maxlen <= strlen(tmp)
  * dump_td_info() doesn't really need to be a function
  * Don't silently terminate td when no I/O performed due to error
  * backend: include data direction in debug poisson rate print
  * Split poisson rate control into read/write/trim
  * engine: add ftruncate ioengine
  * engine: e4defrag fix error reporting
* Mon Apr 10 2017 mpluskal@suse.com
- Update to version 2.19:
  * See http://brick.kernel.dk/snaps/fio-2.19.shortlog.txt
* Fri Mar 24 2017 mpluskal@suse.com
- Update to version 2.18:
  * See http://brick.kernel.dk/snaps/fio-2.16.shortlog.txt
  * See http://brick.kernel.dk/snaps/fio-2.17.shortlog.txt
* Fri Jan  6 2017 mpluskal@suse.com
- Update to version 2.16:
  * See http://brick.kernel.dk/snaps/fio-2.16.shortlog.txt
- Add gpg signature
* Thu Nov  3 2016 mpluskal@suse.com
- Update to version 2.15:
  * See http://brick.kernel.dk/snaps/fio-2.15.shortlog.txt
* Sun Aug 28 2016 mpluskal@suse.com
- Update to version 2.13:
  * workqueue: rename private to priv for compiling as c++
  * verify: Reset verify_state before verification phase.
  * HOWTO: remove old use cases for the net IO engine
  * gfio: call g_thread_init() for <= 2.31.0
  * iolog: flush_log() can be bool
  * Merge branch 'fix_verify' of
    https://github.com/charles-jacobsen/fio
  * pthread: bump min stack size
  * log: fix missing entries
  * log: fix averaged latency logging
  * samples being added to the pending log were silently dropped
    because we failed to set nr_samples in the new log they get
    copied into
  * drifting in output of interval-averaged values was eventually
    causing IOP samples to be dropped.
  * plot: add gnuplot 5 support
  * plot: indicate that the pattern is a glob
  * Add os_trim() support for DragonFlyBSD
  * Add os_trim() support for FreeBSD
  * Fix wrong cpuio option name in documentation
  * Add CPU affinity support for DragonFlyBSD
  * Make I/O priority option generic for non-Linux environment
  * Add ioprio_set() support for DragonFlyBSD
  * Change ARCH_X86_64_h to ARCH_X86_64_H
  * Add os/os-linux-syscall.h to separate syscall NR from arch
    headers
  * Add missing header inclusion for Android from 1c764dbe
  * Remove hard-coded precision for printing JSON float values
  * helper_thread: remove impossible branch
  * Fix "exitall_on_error" option     "exitall_on_error" option
    should be enabled without any argument.
* Sat Jul 16 2016 mpluskal@suse.com
- Enable support for RBD
* Thu Jun 16 2016 mpluskal@suse.com
- Update to version 2.12:
  * No changelog available
* Fri May 27 2016 mpluskal@suse.com
- Update to version 2.11:
  * No changelog available
* Sun May 22 2016 mpluskal@suse.com
- Update to version 2.10:
  * No changelog available
* Mon Apr  4 2016 mpluskal@suse.com
- Update dependencies (enable rdmca)
* Wed Mar 16 2016 lmb@suse.com
- Update to 2.8
  * verify: clear IO verify state all_io_list before writing
  * Revert "options: move pattern_fmt_desc where we need it"
  * lib/rand: make __init_randX() static
  * Use 32-bit rand for parts that use rand_between()
  * t/gen-rand: use 32-bit random generator
  * Fix compile of test programs on archs that use arch_flags at runtime
  * t/gen-rand: remove compile warning on 32-bit
  * .gitignore: ignore vim undo files
  * Add t/gen-rand to test random generator
  * Update documentation on log file formats
  * rand: use bools
  * Add the sample JESD219 job file
  * io_u: speed up __get_next_buflen()
  * options: improvements to parse dry run
  * options: finish merge of bssplit/rand zone code
  * options: unify the bssplit/zone split code
  * Fix double free of td zone state index
  * Log to parent instead of twice to child td
  * options: clean number of zones if we fail parsing
  * Add support for zones of random IO, with varying frequency of access
  * Update documentation for random_distribution=gauss
  * Add support for preadv2/pwritev2
  * ioengines: account any queued IO on the engine side
  * backend: ensure that fio_io_sync() commits IN on queued status
  * Allow IO engine driven allocations of IO structures
  * Allow for the include file specification to be relative.
  * fio.1: man page fixes
  * Update documentation
  * server: don't make SO_REUSEPORT errors fatal
  * diskutil: don't print terse disk util twice for json,terse output format
  * diskutil: fix segfault for both json and terse output
  * io_ddir: io_ddir_name array should be static
  * fio: fix copy/paste error in io_ddir.h
  * log: add support for logging max instead of averages
  * stat: cleanup average logging
  * fio: fix ignore_error regression
  * libmtd: compile fix for linux header changes.
  * Makefile: false positive on _FORTIFY_SOURCE
  * Add a note of what is the default value for random_generator
  * server: send trigger state inline
  * client: fix double removal of client on job file open failure
* Tue Feb  9 2016 mpluskal@suse.com
- Update to 2.6
  * Fix Windows build: define rand_r()
  * powerpc: fix cpus_online() to get correct max CPU number for
    powerpc64
  * ioengine: remove duplicate queue handler check
  * server: use the wrapped MSG_DONTWAIT
  * Makefile: fix duplicate strcasestr for windows
  * client: remove debug printf() for compressed iolog
  * server: disable pdu length check for now
  * server: split vectored commands into fragments
- Changes for 2.5/2.4
  * use option smaalloc_pool_size
  * client: rename send_file() to fio_send_file()
  * lib/pattern: include oslib/strcasestr.h
  * Fix included getopt locations
  * t/genzipf: fix for strcasestr missing
  * t/dedupe: silence bogus warning on 'bytes' being used
    uninitialized
  * configure: check if lex requires/fails with -o for output
  * configure: add --enable-lex
  * options: make the groups/categories constant
  * options: split out option grouping code
  * options: we don't need the crc32c verify include
  * options: move pattern_fmt_desc where we need it
  * server: include name of verify file requested for error message
  * configure: lex force off
  * server: sk_out exit error handling
  * verify: split out state header code
  * verify-state: forward declare io_u
  * Merge branch 'master' of git://github.com/ezrapedersen/fio
  * t/verify-state: add helper to inspect verify dump state files
  * options: fix bs_cmp()
  * Always create server sk_out key
  * Destroy sk_out server key when we are done
  * t/verify-state: fix type for printf
  * t/verify-state: one more printf type fix
  * io_u: ensure that we align new start offset properly for
    time_based
  * Fix issue with termination before io_size has been reached
  * client: drain text output when exiting
  * client: fix non-text command leak
  * init: increment stat count if parent == default thread
  * init: fix compile for FIO_INC_DEBUG not being set
  * mutex: fix double unlock in fio_mutex_down_timeout()
  * Disable libaio for ESXi build - bug#80
- Enable parallel building
* Sun Jan  3 2016 mpluskal@suse.com
- Update to 2.2.13
  * no changelog available
* Sun Dec  6 2015 mpluskal@suse.com
- Update to 2.2.12
  * no changelog available
* Sun Sep 20 2015 mpluskal@suse.com
- Update to 2.2.10
  * no changelog available
* Mon Jul  6 2015 mpluskal@suse.com
- Update to 2.2.9
  * see http://brick.kernel.dk/snaps/fio-2.2.9.shortlog.txt
* Sat Apr  4 2015 mpluskal@suse.com
- Update to 2.2.6
  * make per-thread IOPS more accurate
  * man page updates
  * misc bugfixes
- Cleanup spec file with spec-cleaner
- Update dependencies
  * enable numa
  * enable glusterfs
* Wed Jan 28 2015 dsterba@suse.cz
- 2.2.5
  - rate limiting improvements
  - verify, checksumming fixes
  - shm support can be made optional
  - lots of statbility fixes
- 2.2.4
  - bugfixes in axmap, cleanups
- 2.2.3
  - cpumask handling fixed
- 2.2.2
  - fixed buffer scrambling
- 2.2.1
  - btrace2fio: -a passes specific options
  - minor bugfixes
- 2.2.0
  - verify_state triggers
  - buffer_pattern to specify the pattern manually
  - make suggestions for unknown options
  - time accounting improvements
  - documentation updates
* Thu Nov 20 2014 dsterba@suse.cz
- 2.1.14
  - arithmetic expressions in jobfiles
  - support for --remote-config
  - net engine updates
  - rbd engine updates
* Fri Oct  3 2014 dsterba@suse.cz
- 2.1.13
  - btrace2fio: new tool to turn trace into fio job file
  - basic dedupe support, job config, standalone tool
* Fri Sep 12 2014 dsterba@suse.cz
- 2.1.12
  - Add support for HDFS IO engine
  - misc ioengine fixes
* Wed Jul 30 2014 dsterba@suse.cz
- 2.1.7
  * file append support
- 2.1.8
  * mixed commandline and global options support
  * fixes for s390
- 2.1.9
  * assorted bugfixes
- 2.1.10
  * glusterfs support
  * aarch64 support
- 2.1.11
  * configurable support for gfapi/rbd
  * server protocol update
  * add log_offset
  * removed --latency-log
  * direct io fo glusterfs
  * iolog: logging improvements (compression) and fixes
* Mon Mar 10 2014 bahid@emc.com
- update to 2.1.6.1:
  * Full support for IPv6 for the net I/O engine.
  * Windows threading fixes.
  * Support for ranges in the 'startdelay' option.
  * Adds rbd (rados block device) engine support.
  * Various fixes for blktrace playback on Linux.
  * Adds OpenBSD support.
  * An option added to manually seed random generators.
  * Various client/server fixes.
  * A fix for a crash on some file locking options.
  * Adds support for fast software-based xxhash, and support for testing checksum speeds.
  * A fix for not always honoring the 'openfiles' setting.
  * Support for setting policy on how to distribute CPUs set for jobs.
  * Support for data retention testing with verify
* Tue Dec 17 2013 termim@gmail.com
- Add HOWTO (job file description) to the docs
* Thu Dec  5 2013 termim@gmail.com
- update to 2.1.4:
  * adds JSON output for client/server
  * fix for Windows build breakage in the previous release
  * fix for ioengine specific options
  * adds support for O_ATOMIC atomic writes on Linux
  * failsafe check for realloc() failure during logging
  * fix for a Solaris thread problem
  * various man page and documentation updates
  * fix for a crash on PowerPC without the mfspr instruction
* Wed Aug  7 2013 pascal.bleser@opensuse.org
- update to 2.1.2:
  * adds basic support for an ACT (aerospike) profile
  * fixes atomic write support
  * adds various parsing fixes
  * makes a big revamp of the included graphing support
  * makes the IOPS log includes bandwidth
  * adds support for specific randomness settings for both reads and writes
  * adds support for random vs. sequential blocksize settings
  * fixes a potential verification failure
  * adds multicast support for the net ioengine
* Fri May 24 2013 Greg.Freemyer@gmail.com
- update to 2.1
  * Integration of the gfio GTK frontend.
  * Better Android integration.
  * The initial file fill honors data compression settings.
  * An option for controlling randomness of I/O (percentage_random) instead of being fully random or fully sequential.
  * Fixes a bug in uneven pattern sizes for verification.
  * Various other important fixes
- start calling ./configure as now described in README
- put the newly included gfio into it's own dedicated sub-package
- add BuildRequres zlib-devel to support compression capability for gfio support
- add BuildRequres gtk2-devel for gfio support
* Mon Apr  8 2013 Greg.Freemyer@gmail.com
- update to 2.0.15
  * adds an --eta-newline option to insert ETA new line at fixed intervals.
  * Fixes for the CPU clock, notably PPC.
  * Fixes for workloads with read/write file locking.
  * A fix for skewed latencies with rated IOPS.
  * Fixes a bug with block sizes varying more than 64x.
  * Improves the LFSR implementation.
  * Fixes missing JSON bandwidth output.
  * Various fixes for the Android platform.
  * Fixes man page installation.
  * Other bugfixes and improvements.
- remove fio-2.0.14-fix-configure.patch, now in upstream
- change Recommends gnuplot to Suggests gnuplot, based on end user feedback
* Mon Mar 25 2013 Greg.Freemyer@gmail.com
- update to 2.0.14
  * Autodetect features with a new configure script when building.
  * Improve ETA for some workloads.
  * Support for verify mode that requires no metadata, greatly reducing memory requirements for big device verify workloads.
  * Ensures fsync is always done, even for direct/raw I/O (if asked to).
  * Support for unified read/write/trim reporting.
  * A few axmap and cpuclock bugfixes.
  * Fixes zones and numjobs used together.
  * Adds support for idle profiling, showing idle system CPU when running a workload.
  * Many other fixes; all users should upgrade
- added patch to fix new configure logic introduced by upstream in 2.0.14
  * fio-2.0.14-fix-configure.patch
* Mon Feb  4 2013 bahid@emc.com
- update to 2.0.13:
  * Fix potential null pointer dereference on verify and requeue events
  * server: move fio_net_cmd to the end of fio_net_int_cmd
  * Use variable[] instead of GCC variable[0] syntax
  * Enable -ffast-math
  * time: convert to uint64_t
  * Use uintptr_t for engine data
  * Start of transition from unsigned long long to uint64_t
  * zipf/pareto: use min of file size and io size for init
  * zipf/pareto: use size= if given, not always device size
  * libaio: use container_of() instead of silly casting
  * gettime: even rounding, don't always round up
  * Move 'tsc_reliable' outside of ARCH_HAVE_CPU_CLOCK
  * implement get_cpu_clock() for s390/s390x
  * clock: turn expensive division into multiply + cheap division
  * t/axmap: update tester for lfsr_init() taking a seed argument
  * Include <stdint.h> before checking __WORDSIZE
- Fio 2.0.12.2
  * Add return statements to arch_init functions for ia64 and ppc.
  * Use clock_gettime() for CPU clock calibration
  * Consistently indent using tabs in Windows files and remove trailing spaces.
  * Create a new Windows installer product GUID for 2.0.12.
  * Fix $(CC) override: use system compiler except on HP-UX and Solaris.
- Fio 2.0.12.1
  * Fixup CPUID for 32-bit x86
- Fio 2.0.12
  * windowsaio: fix typo
  * gettime: make last_cycles thread local too
  * gettime: use pthread_{set,get}specific() for TLS
  * gettime: fix race/bug with threads and time keeping
  * Add --cpuclock-test and clocksource= option help
  * gettime: include per-cpu clock calibration in cpu clock test
  * gettime: locking fix and debug check for identical sequence
  * cpu clock: add independent test for monotonic/sane TSC
  * clock: ensure that we re-init if the clocksource changes from the default
  * obinject: fixup ->file_data breakage
  * file: unify ->file_data and ->file_pos
  * file hash: don't close file fd on lookup/add race
  * cpu clock: round up when dividing by samples
  * Define TSC arch_init() for PPC and IA64
  * gettime: fix CPU calibration reported mean
  * gettime: calibration rounding error
  * Increase CPU clock calibration accuracy
  * Add check for invariant TSC on x86 and use TSC is default clock if reliable
  * windowsaio: create a single completion port during init, associate files during Document the ioengine=net pingpong= option
  * Fix windows out-of-memory handling
  * Free io_u related structures before killing IO engine
  * windowsaio: initialize and map windowsaio IO structure to io_u
  * parser: always match the correct option length for posval options
  * Fix man page indentation
  * lfsr: add HOWTO and man page documentation
  * lfsr: ensure that the cycle follows the randrepeat= setting
  * Name the various random offsets we use
  * Revert "Change preferred default clocksource to gettimeofday()"
  * engines/net.c: fix compilation error due to missing signal.h include
  * Wire up SIGUSR2 to kill blocking threads
  * Change preferred default clocksource to gettimeofday()
  * Cache layout improvements
  * net: fix receiver start time
  * net: add basic ping/pong type workload support
  * verify: treat as failure if given verify type is different from media
  * net: sent udp open messages
  * Merge branch 'rand-map'
  * solaris: enable fadvise()
  * Fix broken 'norandommap' rand-map
  * parse: fix wrong "might be used unitialized" warning on some compilers
  * Wire up _weak posix_fadvise()
  * net: set runstate to SETTING_UP while waiting for a connection
  * net: exit on WAITALL and !ret
  * net: fix segfault with receiver, tcp, and no hostname set
  * libfio: don't sent KILL signal to own process from signal handler
  * Rename the bitmap to axmap
  * bitmap: fix off-by-8 allocation error
  * Fix windowsaio IO error handling and document device write access issue on WindoFix compile for older Linux without mmap MAP_HUGETLB
  * lfsr: crank it 128 times before using the sequence
  * Ensure that lfsr_init() is always called
  * Add LFSR generator
  * Restore BUSY_OK bypassing of bitmap
  * Kill now unused bitmap defines from legacy code
  * bitmap: kill debug code
  * bitmap: fix bit_masks[] for 32-bit compiles
  * Rework file random map
  * Add support for Android
  * memory: wire up mmap huge page support
  * Use unique seed for zipf/pareto init if rand_repeat is not set
  * Generate a new Windows installer product code for 2.0.11.
  * Add more examples to the Windows installer.
- Fio 2.0.11
  * Document random distribution
  * Disable random map automatically if a non-uniform random distribution is given
  * genzipf: add help/usage screen (-h)
  * Get rid of -fno-omit-frame-pointer
  * t/genzfip: add -c option for csv output
  * server: properly reset stat_number in fio_reset_state()
  * client/server: fixup "All clients" reporting
* Thu Oct 18 2012 pascal.bleser@opensuse.org
- update to 2.0.10:
  * support for trim as a primary IO directive
  * addition of the JSON output format for easy parsing by both humans and
    computers
  * fixes for engine starvation for extraordinarily long latencies
  * fallocate() fixes
  * fixes for netio compatibility
  * add support for SIGBREAK
  * the critical error list is now configurable
  * three new IO engines were provided: falloc, e4defrag, and Fusion-io atomic
    write engine
  * a new sample job file was provided for SSD steady state performance
* Tue Oct 16 2012 Greg.Freemyer@gmail.com
- correct License to GPLv2, not GPLv2+  (bnc#783876)
* Fri Oct  5 2012 Greg.Freemyer@gmail.com
- update to 2.0.9
  * A fix for premature freeing of disk utilization structures, and missing
    locking of the same.
  * fio dumps current progress if sent a USR1 signal.
  * Includes git version in version output.
  * A fix for a crash with more than ~500 jobs.
  * Man page updates.
  * A fix for wrap-around behavior for time-based sequential read jobs.
  * A fix for a "file hash not empty" warning on blktrace replay.
  * A fix for compilation on the MIPS architecture.
  * Improved display of commit-rate while running.
  * A fix for fallocate failing on some Linux systems.
  * Includes an end-of-run timestamp in output
* Sat Apr 14 2012 pascal.bleser@opensuse.org
- update to 2.0.7:
  * fixes the terse output when used with a description field
  * enhances display of reaped threads (indicating whether they exited
    normally, were killed, or died due to a signal)
  * removes the assert which could occasionally trigger on verify overwrites
  * fixes the "Group run status" aggrb field
* Fri Mar 30 2012 pascal.bleser@opensuse.org
- update to 2.0.6:
  * a new offset_increment option to more easily be able to have different
    threads use different regions of a file/device
  * a new buffer_compression_percentage option enabling the user to specify the
    compression ratio to expect from the data written by fio
  * a fix for a segfault caused by invalid verification job files
  * a few client/server bugfixes
  * a fix for a bug that caused early termination of fio with verify_backlog
  * a fix for a problem with iodepth_batch_complete=0 and accounting
  * enables read/write sequential offset to be a non-multiple of the block size
- changes from 2.0.5:
  * a bug affecting IOPS logging was fixed
* Sun Feb 26 2012 pascal.bleser@opensuse.org
- update to 2.0.4: too many changes to list, consult documentation
* Fri Sep 30 2011 pascal.bleser@opensuse.org
- update to 1.58:
  * adds an RDMA IO engine
  * adds support for direct userspace reaping of completed events with libaio
    IO engine
  * ensures that bool options also work if given a parameter
  * adds support for "holed" IO patterns
  * fixes a latency reporting bug
  * fixes a disk utilization bug for delayed jobs
  * adds resolution support to fio_generate_plots
  * fixes summed computation of standard deviation
  * adds completion latency percentile support
  * fixes lots of other minor bugs
* Fri Jul 22 2011 pascal.bleser@opensuse.org
- update to 1.57:
  * fixes an infinite loop on platforms with very limited number of AIO request
    depth support
  * fixes an issue with killing of threads that haven't started yet
* Mon May 30 2011 pascal.bleser@opensuse.org
- update to 1.55:
  * an issue was fixed with the splice IO engine, in which it didn't work
    correctly on file systems that did not support O_DIRECT
  * an issue was fixed where IO could span two separate regions, causing write
    verify failures
* Fri May 13 2011 pascal.bleser@opensuse.org
- update to 1.54:
  * a 32-bit randomness problem has been fixed
  * a crash with giving a bad --ioengine command line option has been fixed
* Fri May  6 2011 pascal.bleser@opensuse.org
- update to 1.53:
  * this is a maintenance release, fixing a few important bugs
  * the runtime option was broken due to a bad change
- fix compiling with optflags
* Fri Apr 29 2011 pascal.bleser@opensuse.org
- update to 1.52:
  * an end-of-job slowdown for big random workloads was fixed
  * support was added for running multiple sections at the time with the
  - -section option
  * a parser bug with range options and size postfix was fixed
  * an internal random generator is now used for IO offsets
- changes from 1.50:
  * new features for blktrace replay
  * fixes a slowdown bug in the posixaio engine
  * adds a binject I/O engine
  * adds support for TRIM/DISCARD operations
  * extends I/O verification to dump good and bad data on failure for better
    post mortem analysis
  * various speedups and optimizations
  * a lot of obscure bugs have been found and fixed
* Fri Jun 18 2010 pascal.bleser@opensuse.org
- update to 1.41:
  * adds support for explicit clocksources
  * speeds random buffer fills
  * improves ETA calculation for workloads using "fill_device"
  * fixes a bug with --section matching
  * adds improvements for verifying workloads
  * add support for offloading "verify" to dedicated threads
  * fixes strict non-overlap random workloads
  * fixes a bug in matching strings in the parser
- update to 1.38:
  * fixes a bug in sha256 that prevented it from doing correct verifies
  * fixes a bug with mixed block size ranges and verify
  * now uses the minimum block size as the verify interval
  * command size length was increased
  * initial support for benchmark profiles was added ('tiobench' is now such a
    profile)
  * a few parser bugs were fixed
  * support for 'sync_file_range()' on Linux
  * a few places where errors would not get reported were fixed
  * overhead of the IO path was reduced in a few places
* Tue Feb 23 2010 pascal.bleser@opensuse.org
- update to 1.37:
  * a bug in sha256 calculation was fixed
  * bad use of lstat(), causing problems with links to devices, was fixed
  * a specific fallocate() control switch was added
  * CPU utilization of sequential sync IO was reduced
- changes from 1.36:
  * simple math support and reserved keywords were added to job
    file
  * initial support for benchmark profiles was added
  * support for cgroup based IO controllers on Linux was added
  * verify failure logging was improved
  * a bug with rate IO and queuing IO engines was fixed
* Thu Nov  5 2009 pascal.bleser@opensuse.org
- update to 1.35:
  * fixes some parser bugs
  * fixes the shared memory allocator
  * reserved keywords are now supported in job files
  * a few fixes were made for verifying workloads
  * fixed a hang when resolving component devices of md/dm arrays
  * IO log replay fixes and additions were made
  * fixed a hang due to an incorrect mutex clock source
  * added support for wider than 32-bit pattern verifies
  * fixed a few races when using async verifier threads
  * fixed a hang with the async engine and IO depth batch settings
* Thu Jul  9 2009 pascal.bleser@opensuse.org
- update to 1.31:
  * fixes completion latency numbers (they would read 0)
  * fixes an alignment bug
  * improves the speed of the mmap engine on 64-bit architectures
  * adds support for asynchronous "verify" offload threads to speed "verify"
    workloads
- changes from 1.29:
  * fixes and improvements for the IO limiting rate option
  * fix for submission latency numbers in some cases
  * fix for a bug in the job parser that would sometimes truncate the postfix
    value when multiple values were given
  * a continue_on_error option was added to allow a job to keep running if it
    sees non-fatal errors
  * a bug in the mmap engine with large files and 32-bit machines was fixed
  * support for fdatasync() was added with the fdatasync option
  * an iomem_align option was added for fine-grained control over IO buffer
    memory alignment
  * the pre_read option was fixed and no longer attempts to pre-read on IO
    engines that cannot seek
* Tue Jun  2 2009 pascal.bleser@opensuse.org
- update to 1.27:
  * corruption of submission/completion latency logs for shared files was fixed
  * blocksizes are included in latency logs
  * a "pre_read" option was added to pre-read files into memory before starting
    the job
  * exec_prerun/postrun now invokes a shell
  * accuracy of disk util stats was improved
  * large files are supported with an mmap engine on 32-bit architectures
  * ETA stats were improved with better throughput reporting, and IOPS
    reporting was added there too
  * the man page was fixed based on lintian
* Tue Apr 21 2009 pascal.bleser@opensuse.org
- update to 1.26:
  * a crash with multiple files for a job was fixed
  * reporting of throughput was corrected, as it was sometimes off by about
    2.4%%
  * IO logging is allowed for diskless engines
  * support was added for different weights for reads and writes with the
    bssplit= option
  * a crash with engines not supporting get_file_size() was fixed
  * a sample SSD performance analysis job was added
  * a problem was fixed with IO offsets sometimes being too large, causing
    early exit of failed IO verification
* Mon Feb  9 2009 guru@unixtech.be
- update to 1.24:
  * UDP support to the network IO engine
  * gettimeofday() optimizations
  * fixes a bug related to crashing the parser
  * fixes various bugs in the shared memory allocator
  * fixes /tmp file leaks
  * fixes CPU mask options on large systems
* Thu Oct  9 2008 guru@unixtech.be
- update to 1.22:
  * adds support for hardware accelerated CRC-32 calculation for verification
    (on supported Intel platforms w/SSE4.2)
  * adds option priorities to get rid of manual option ordering
  * increase the range of the smalloc allocator
  * adds a ramp time option to allow job warm up before doing any measurements
  * adds support for detailing RAID/LVM component utilization
  * many little bugfixes
* Fri Jun  6 2008 guru@unixtech.be
- new upstream version
* Tue Apr 29 2008 guru@unixtech.be
- new upstream version
* Sun Feb 17 2008 guru@unixtech.be
- new upstream version
* Mon Feb  4 2008 guru@unixtech.be
- new upstream version
* Thu Jan 31 2008 guru@unixtech.be
- new upstream version
* Sat Dec 29 2007 guru@unixtech.be
- moved to benchmark
* Mon Oct 29 2007 guru@unixtech.be
- moved to openSUSE Build Service
- new upstream version
* Tue Aug 14 2007 guru@unixtech.be
- new upstream version
* Mon Jun 18 2007 guru@unixtech.be
- new upstream version
* Tue Apr 24 2007 guru@unixtech.be
- new upstream version
* Tue Mar 27 2007 guru@unixtech.be
- new upstream version
* Tue Mar 13 2007 guru@unixtech.be
- new upstream version
- CHANGES: group reporting was added for better handling of large jobs
- CHANGES: error handling and reporting were improved
- CHANGES: IOPS reporting was added
- CHANGES: handling an arbitrary number of files is supported
- CHANGES: the 'opendir' option was added for opening a full tree
- CHANGES: lots of bugfixes, improvements, and cleanups were done
* Fri Mar  2 2007 guru@unixtech.be
- new upstream version
* Thu Dec 21 2006 guru@unixtech.be
- new upstream version
* Thu Nov  9 2006 guru@unixtech.be
- new upstream version
* Sun Oct 22 2006 guru@unixtech.be
- new upstream version
* Wed Aug 30 2006 guru@unixtech.be
- dropped stonewall patch, was merged upstream
- new upstream version
* Tue Jun 13 2006 guru@unixtech.be
- new upstream version
* Sun Jun  4 2006 guru@unixtech.be
- new upstream version
* Thu May  4 2006 guru@unixtech.be
- added binary stripping on SUSE < 9.3
- removed Packager and Distribution, injected by rpmmacros
- new upstream version
* Tue Dec  6 2005 guru@unixtech.be
- new package
